==> ejc-scene-impl-3.0.0-20250412.044330-218-sources.jar: com/ejianc/business/scene/bean/EquipmentManageEntity.java <==
package com.ejianc.business.scene.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 设备设施管理
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scene_equipment manage")
public class EquipmentManageEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="category_name")
    private String categoryName; // 类别
    @TableField(value="name")
    private String name; // 名称
    @TableField(value="code")
    private String code; // 管理编号
    @TableField(value="deliver_date")
    private Date deliverDate; // 交付日期
    @TableField(value="warranty_start_date")
    private Date warrantyStartDate; // 质保开始时间
    @TableField(value="warranty_end_date")
    private Date warrantyEndDate; // 质保结束时间
    @TableField(value="asset_flag")
    private String assetFlag; // 是否固定资产
    @TableField(value="original_mny")
    private BigDecimal originalMny; // 原值
    @TableField(value="residual_mny")
    private BigDecimal residualMny; // 残值
    @TableField(value="address")
    private String address; // 描述
    @TableField(value="contract_name")
    private String contractName; // 采购合同
    @TableField(value="regist_flag")
    private String registFlag; // 资产在册与否
    @TableField(value="manage_flag")
    private String manageFlag; // 管理在册与否
    @TableField(value="deliver_company")
    private String deliverCompany; // 交付来源单位
    @TableField(value="link_company")
    private String linkCompany; // 联系单位
    @TableField(value="relationship")
    private String relationship; // 关系
    @TableField(value="nature")
    private String nature; // 性质
    @TableField(value="link_user")
    private String linkUser; // 联系人
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="discount_mny")
    private BigDecimal discountMny; // 累计折扣金额
    
    
    

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Date getDeliverDate() {
        return deliverDate;
    }

    public void setDeliverDate(Date deliverDate) {
        this.deliverDate = deliverDate;
    }
    public Date getWarrantyStartDate() {
        return warrantyStartDate;
    }

    public void setWarrantyStartDate(Date warrantyStartDate) {
        this.warrantyStartDate = warrantyStartDate;
    }
    public Date getWarrantyEndDate() {
        return warrantyEndDate;
    }

    public void setWarrantyEndDate(Date warrantyEndDate) {
        this.warrantyEndDate = warrantyEndDate;
    }
    public String getAssetFlag() {
        return assetFlag;
    }

    public void setAssetFlag(String assetFlag) {
        this.assetFlag = assetFlag;
    }
    public BigDecimal getOriginalMny() {
        return originalMny;
    }

    public void setOriginalMny(BigDecimal originalMny) {
        this.originalMny = originalMny;
    }
    public BigDecimal getResidualMny() {
        return residualMny;
    }

    public void setResidualMny(BigDecimal residualMny) {
        this.residualMny = residualMny;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getRegistFlag() {
        return registFlag;
    }

    public void setRegistFlag(String registFlag) {
        this.registFlag = registFlag;
    }
    public String getManageFlag() {
        return manageFlag;
    }

    public void setManageFlag(String manageFlag) {
        this.manageFlag = manageFlag;
    }
    public String getDeliverCompany() {
        return deliverCompany;
    }

    public void setDeliverCompany(String deliverCompany) {
        this.deliverCompany = deliverCompany;
    }
    public String getLinkCompany() {
        return linkCompany;
    }

    public void setLinkCompany(String linkCompany) {
        this.linkCompany = linkCompany;
    }
    public String getRelationship() {
        return relationship;
    }

    public void setRelationship(String relationship) {
        this.relationship = relationship;
    }
    public String getNature() {
        return nature;
    }

    public void setNature(String nature) {
        this.nature = nature;
    }
    public String getLinkUser() {
        return linkUser;
    }

    public void setLinkUser(String linkUser) {
        this.linkUser = linkUser;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getDiscountMny() {
        return discountMny;
    }

    public void setDiscountMny(BigDecimal discountMny) {
        this.discountMny = discountMny;
    }
    
}

==> ejc-scene-impl-3.0.0-20250412.062036-221-sources.jar: com/ejianc/business/scene/bean/EquipmentManageEntity.java <==
package com.ejianc.business.scene.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 设备设施管理
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scene_equipment_manage")
public class EquipmentManageEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="category_name")
    private String categoryName; // 类别
    @TableField(value="name")
    private String name; // 名称
    @TableField(value="code")
    private String code; // 管理编号
    @TableField(value="deliver_date")
    private Date deliverDate; // 交付日期
    @TableField(value="warranty_start_date")
    private Date warrantyStartDate; // 质保开始时间
    @TableField(value="warranty_end_date")
    private Date warrantyEndDate; // 质保结束时间
    @TableField(value="asset_flag")
    private String assetFlag; // 是否固定资产
    @TableField(value="original_mny")
    private BigDecimal originalMny; // 原值
    @TableField(value="residual_mny")
    private BigDecimal residualMny; // 残值
    @TableField(value="address")
    private String address; // 描述
    @TableField(value="contract_name")
    private String contractName; // 采购合同
    @TableField(value="regist_flag")
    private String registFlag; // 资产在册与否
    @TableField(value="manage_flag")
    private String manageFlag; // 管理在册与否
    @TableField(value="deliver_company")
    private String deliverCompany; // 交付来源单位
    @TableField(value="link_company")
    private String linkCompany; // 联系单位
    @TableField(value="relationship")
    private String relationship; // 关系
    @TableField(value="nature")
    private String nature; // 性质
    @TableField(value="link_user")
    private String linkUser; // 联系人
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="discount_mny")
    private BigDecimal discountMny; // 累计折扣金额
    
    
    

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Date getDeliverDate() {
        return deliverDate;
    }

    public void setDeliverDate(Date deliverDate) {
        this.deliverDate = deliverDate;
    }
    public Date getWarrantyStartDate() {
        return warrantyStartDate;
    }

    public void setWarrantyStartDate(Date warrantyStartDate) {
        this.warrantyStartDate = warrantyStartDate;
    }
    public Date getWarrantyEndDate() {
        return warrantyEndDate;
    }

    public void setWarrantyEndDate(Date warrantyEndDate) {
        this.warrantyEndDate = warrantyEndDate;
    }
    public String getAssetFlag() {
        return assetFlag;
    }

    public void setAssetFlag(String assetFlag) {
        this.assetFlag = assetFlag;
    }
    public BigDecimal getOriginalMny() {
        return originalMny;
    }

    public void setOriginalMny(BigDecimal originalMny) {
        this.originalMny = originalMny;
    }
    public BigDecimal getResidualMny() {
        return residualMny;
    }

    public void setResidualMny(BigDecimal residualMny) {
        this.residualMny = residualMny;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getRegistFlag() {
        return registFlag;
    }

    public void setRegistFlag(String registFlag) {
        this.registFlag = registFlag;
    }
    public String getManageFlag() {
        return manageFlag;
    }

    public void setManageFlag(String manageFlag) {
        this.manageFlag = manageFlag;
    }
    public String getDeliverCompany() {
        return deliverCompany;
    }

    public void setDeliverCompany(String deliverCompany) {
        this.deliverCompany = deliverCompany;
    }
    public String getLinkCompany() {
        return linkCompany;
    }

    public void setLinkCompany(String linkCompany) {
        this.linkCompany = linkCompany;
    }
    public String getRelationship() {
        return relationship;
    }

    public void setRelationship(String relationship) {
        this.relationship = relationship;
    }
    public String getNature() {
        return nature;
    }

    public void setNature(String nature) {
        this.nature = nature;
    }
    public String getLinkUser() {
        return linkUser;
    }

    public void setLinkUser(String linkUser) {
        this.linkUser = linkUser;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getDiscountMny() {
        return discountMny;
    }

    public void setDiscountMny(BigDecimal discountMny) {
        this.discountMny = discountMny;
    }
    
}
